@@ -13,6 +13,9 @@ VKGallery::VKGallery(QWidget *parent) :
     (void) new QShortcut(Qt::CTRL + Qt::Key_Q, this, SLOT(close()));
 
     this->sm = new ServiceMgr(this);
+    this->sm->canUpdateAlbums = true;
+    this->sm->canUpdateFeeds = true;
+    this->sm->canUpdateFriends = true;
 
     connect(sm, SIGNAL(errorOccured(QString, QTransport::Action, bool)), this, SLOT(gotErrorMsg(QString, QTransport::Action, bool)));
 
@@ -204,10 +207,10 @@ void VKGallery::gotErrorMsg(QString errorMsg, QTransport::Action acc, bool isMaj
     /* Create notification */
 #if NOTIFY_VERSION > 070
     notification = notify_notification_new(APP_NAME,
-        errorMsg.toUtf8().data(), "msagallery");
+        errorMsg.toUtf8().data(), ICONPATH);
 #else
     notification = notify_notification_new(APP_NAME,
-        errorMsg.toUtf8().data(), "msagallery", NULL);
+        errorMsg.toUtf8().data(), ICONPATH, NULL);
 #endif
     if (notification) {
         /* Set timeout */
